@@ -37,7 +37,7 @@ public class Image extends GObject
 	 */
 	public Colormap getColormap() {
 	    Handle hndl = gdk_image_get_colormap(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Colormap)obj;
 		return new Colormap(hndl);
