@@ -32,10 +32,6 @@ public class Gtk
 	 */
 	public static void init(String[] args) {
 	    int [] argLen = new int[1];
-	    // I add one to the length since the makeArgv
-	    // method will add one additional parameter to
-	    // the array.
-	    argLen[0] = args.length+1;
 
 	    String appName = System.getProperty("gnome.appName", "java-gnome");
 
@@ -47,6 +43,7 @@ public class Gtk
 			newArr[0] = appName;
 			args = newArr;
 		}
+		argLen[0] = args.length;
 	    Gtk.gtk_init(argLen, args);
 	}
 	
@@ -131,6 +128,45 @@ public class Gtk
         return gtk_main_iteration_do( blocking );
     }
 
+    // Private data members for keysnooping data.
+    private static KeySnoopMethod keySnooperMethod = null;
+    private static int keySnooperId = 0;
+    /**
+     * Installs a key snooper method, which will get called on all
+     * key events before delivering them normally.  This can be used to 
+     * implement custom key event handling.
+     */
+    public static void setKeySnoopMethod( KeySnoopMethod method ) {
+        keySnooperId = gtk_key_snooper_install( method, 
+                                                "handleKeySnoopEvent" );
+        keySnooperMethod = method;
+    }
+    /**
+     * Removes current the key snooper method.
+     */
+    public static void removeKeySnoopMethod() {
+        gtk_key_snooper_remove( keySnooperId );
+        keySnooperMethod = null;
+        keySnooperId = 0;
+    }
+
+    protected static boolean handleKeySnoopEvent( Handle widget, 
+                                                  Handle event ) {
+        if ( keySnooperMethod != null ) {
+            Widget widg = null;
+            GObject obj = GObject.getGObjectFromHandle( widget );
+            if ( obj == null ) {
+                widg = new Widget( widget );
+            } else {
+                widg = (Widget)obj;
+            }
+            EventKey evt = new EventKey( event );
+            return keySnooperMethod.keyEvent( widg, evt );
+        } else {
+            return false;
+        }
+    }
+
     /**
      * Sends an event to a widget, propagating the event to parent
      * widgets if the event remains unhandled.
@@ -175,6 +211,8 @@ public class Gtk
     native static final private boolean gtk_true();
     native static final private boolean gtk_false();
     native static final private boolean gtk_main_iteration_do(boolean blocking);
+    native static final private int gtk_key_snooper_install(KeySnoopMethod snooper, String callback);
+    native static final private void gtk_key_snooper_remove(int snooper_handler_id);
     native static final private void gtk_propagate_event(Handle widget, Handle event);
 
     /* Undocumented functions.
