@@ -9,6 +9,8 @@
 
 package org.gnu.gtk.event;
 
+import org.gnu.glib.EventType;
+
 
 /**
  * An event represeting action by a {@link org.gnu.gtk.CellEditable} class.
@@ -19,7 +21,7 @@ public class CellEditableEvent extends GtkEvent {
 	/**
 	 * Type of a CellEditableEvent
 	 */
-	public static class Type extends GtkEventType {
+	public static class Type extends EventType {
 		private Type(int id, String name) {
 			super(id, name);
 		}
